@@ -10,6 +10,7 @@ References:
         * https://www.cyberforum.ru/blogs/105416/blog3671.html
 """
 import sys
+import os
 from ctypes import c_ulonglong, POINTER, Structure, HRESULT
 from ctypes.wintypes import (
     UINT,
@@ -24,6 +25,7 @@ from ctypes.wintypes import (
     SIZE,
     DWORD,
 )
+from typing import Any, Iterator
 from comtypes import (
     IUnknown,
     GUID,
@@ -31,10 +33,13 @@ from comtypes import (
     COMMETHOD,
 )
 
-# See https://github.com/Ciantic/VirtualDesktopAccessor/issues/33
-# https://github.com/mzomparelli/zVirtualDesktop/wiki
-WINDOWS_BUILD = sys.getwindowsversion().build
-BUILD_OVER_20231 = WINDOWS_BUILD >= 20231
+if not os.getenv("READTHEDOCS"):
+    # See https://github.com/Ciantic/VirtualDesktopAccessor/issues/33
+    # https://github.com/mzomparelli/zVirtualDesktop/wiki
+    WINDOWS_BUILD = sys.getwindowsversion().build
+    BUILD_OVER_20231 = WINDOWS_BUILD >= 20231
+else:
+    BUILD_OVER_20231 = False
 
 
 CLSID_ImmersiveShell = GUID("{C2F03A33-21F5-47FA-B4BB-156362A2F239}")
@@ -42,7 +47,7 @@ CLSID_VirtualDesktopManagerInternal = GUID("{C5E0CDCA-7B6E-41B2-9FC4-D93975CC467
 CLSID_IVirtualDesktopManager = GUID("{AA509086-5CA9-4C25-8F95-589D3C07B48A}")
 CLSID_VirtualDesktopPinnedApps = GUID("{B5A399E7-1C87-46B8-88E9-FC5747B171BD}")
 
-# Ignore following API's:
+# Ignore following APIs:
 IAsyncCallback = UINT
 IImmersiveMonitor = UINT
 APPLICATION_VIEW_COMPATIBILITY_POLICY = UINT
@@ -80,6 +85,15 @@ class IObjectArray(IUnknown):
         STDMETHOD(HRESULT, "GetAt", (UINT, REFIID, POINTER(LPVOID),)),
     ]
 
+    def get_at(self, i: int, cls: Any) -> Any:
+        item = POINTER(cls)()
+        self.GetAt(i, cls._iid_, item)
+        return item
+
+    def iter(self, cls: Any) -> Iterator[Any]:
+        for i in range(self.GetCount()):
+            yield self.get_at(i, cls)
+
 
 # Computer\HKEY_LOCAL_MACHINE\SOFTWARE\Classes\Interface\{372E1D3B-38D3-42E4-A15B-8AB2B178F513}
 # Found with searching "IApplicationView"
@@ -97,14 +111,12 @@ IApplicationView._methods_ = [
     STDMETHOD(HRESULT, "TryInvokeBack", (POINTER(IAsyncCallback),)),
     COMMETHOD([], HRESULT, "GetThumbnailWindow", (["out"], POINTER(HWND), "hwnd")),
     STDMETHOD(HRESULT, "GetMonitor", (POINTER(POINTER(IImmersiveMonitor)),)),
-    # STDMETHOD(HRESULT, "GetVisibility", (POINTER(UINT),)),
     COMMETHOD([], HRESULT, "GetVisibility", (["out"], POINTER(UINT), "pVisible")),
     STDMETHOD(HRESULT, "SetCloak", (APPLICATION_VIEW_CLOAK_TYPE, UINT,)),
     STDMETHOD(HRESULT, "GetPosition", (REFIID, POINTER(LPVOID),)),
     STDMETHOD(HRESULT, "SetPosition", (POINTER(IApplicationViewPosition),)),
     STDMETHOD(HRESULT, "InsertAfterWindow", (HWND,)),
     STDMETHOD(HRESULT, "GetExtendedFramePosition", (POINTER(RECT),)),
-    # STDMETHOD(HRESULT, "GetAppUserModelId", (POINTER(PWSTR),)),
     COMMETHOD([], HRESULT, "GetAppUserModelId", (["out"], POINTER(PWSTR), "pId")),
     STDMETHOD(HRESULT, "SetAppUserModelId", (LPCWSTR,)),
     STDMETHOD(HRESULT, "IsEqualByAppUserModelId", (LPCWSTR, POINTER(UINT),)),
@@ -178,7 +190,7 @@ class IVirtualDesktopManagerInternal(IUnknown):
         STDMETHOD(HRESULT, "MoveViewToDesktop", (POINTER(IApplicationView), POINTER(IVirtualDesktop))),
         # Since build 10240
         STDMETHOD(HRESULT, "CanViewMoveDesktops", (POINTER(IApplicationView), POINTER(UINT))),
-        STDMETHOD(HRESULT, "GetCurrentDesktop", (POINTER(POINTER(IVirtualDesktop)),)),
+        COMMETHOD([], HRESULT, "GetCurrentDesktop", (["out"], POINTER(POINTER(IVirtualDesktop)), "pDesktop"),),
         COMMETHOD([], HRESULT, "GetDesktops", (["out"], POINTER(POINTER(IObjectArray)), "array")),
         STDMETHOD(HRESULT, "GetAdjacentDesktop", (
             POINTER(IVirtualDesktop), AdjacentDesktop, POINTER(POINTER(IVirtualDesktop)),
@@ -200,7 +212,6 @@ class IVirtualDesktopManager(IUnknown):
             (["in"], HWND, "hwnd"),
             (["out"], POINTER(BOOL), "isOnCurrent"),
         ),
-        # STDMETHOD(HRESULT, "IsWindowOnCurrentVirtualDesktop", (HWND, POINTER(BOOL))),
         STDMETHOD(HRESULT, "GetWindowDesktopId", (HWND, POINTER(GUID))),
         STDMETHOD(HRESULT, "MoveWindowToDesktop", (HWND, REFGUID)),
     ]
@@ -240,7 +251,7 @@ class IApplicationViewCollection(IUnknown):
         ),
         STDMETHOD(HRESULT, "GetViewForApplication", (POINTER(IImmersiveApplication), POINTER(POINTER(IApplicationView)))),
         STDMETHOD(HRESULT, "GetViewForAppUserModelId", (LPCWSTR, POINTER(POINTER(IApplicationView)))),
-        STDMETHOD(HRESULT, "GetViewInFocus", (POINTER(POINTER(IApplicationView)),)),
+        COMMETHOD([], HRESULT, "GetViewInFocus", (["out"], POINTER(POINTER(IApplicationView)), "view")),
         STDMETHOD(HRESULT, "Unknown1", (POINTER(POINTER(IApplicationView)),)),
         STDMETHOD(HRESULT, "RefreshCollection", ()),
         STDMETHOD(HRESULT, "RegisterForApplicationViewChanges", (POINTER(IApplicationViewChangeListener), POINTER(DWORD))),
